@@ -12,7 +12,7 @@ def _get_type_info(field):
     if isinstance(field, AnyOf):
         union_fields = getattr(field, "_fields", [])
         if len(union_fields) == 2 and isinstance(union_fields[1], NoneField):
-            return f"Optional[{_get_type_info(union_fields[0])}]"
+            return f"Optional[{_get_type_info(union_fields[0])}] = None"
 
         fields = ",".join([_get_type_info(f) for f in union_fields])
         return f"Union[{fields}]"
@@ -42,7 +42,7 @@ def _get_all_type_info(cls) -> dict:
             and required is not None
             and not type_info_str.startswith("Optional[")
         ):
-            type_info_str = f"Optional[{type_info_str}]"
+            type_info_str = f"Optional[{type_info_str}] = None"
         type_by_name[field_name] = type_info_str
 
     return type_by_name
@@ -74,6 +74,12 @@ def _get_imported_classes(attrs):
     ]
 
 
+def _get_ordered_args(unordered_args: dict):
+    optional_args = {k:v for k,v in unordered_args.items() if v.endswith("= None")}
+    mandatory_args = {k:v for k,v in unordered_args.items() if k not in optional_args}
+    return {**mandatory_args, **optional_args}
+
+
 def create_pyi(calling_source_file, attrs: dict, only_current_module: bool = True):
     full_path: Path = Path(calling_source_file)
     pyi_path = (full_path.parent / f"{full_path.stem}.pyi").resolve()
@@ -96,15 +102,16 @@ def create_pyi(calling_source_file, attrs: dict, only_current_module: bool = Tru
         if not info:
             continue
 
+        ordered_args = _get_ordered_args(info)
         out_src.append(f"class {cls_name}(Structure):")
-        init_params = f",\n{INDENT*2}".join([f"{k}: {v}" for k, v in info.items()])
+        init_params = f",\n{INDENT*2}".join([f"{k}: {v}" for k, v in ordered_args.items()])
         kw_opt = (
             f",\n{INDENT*2}**kw" if getattr(cls, "_additionalProperties", True) else ""
         )
         out_src.append(f"    def __init__(self, {init_params}{kw_opt}\n{INDENT}): ...")
         out_src.append("")
 
-        for field_name, type_name in info.items():
+        for field_name, type_name in ordered_args.items():
             out_src.append(f"    {field_name}: {type_name}")
         out_src.append("\n")
 
